@@ -1,4 +1,5 @@
 """Util functions to cleanup disk space."""
+
 import gzip
 import logging
 import os
@@ -8,6 +9,13 @@ import time
 from argparse import ArgumentDefaultsHelpFormatter
 from datetime import datetime, timedelta
 
+try:
+    from datetime import UTC
+except ImportError:
+    from datetime import timezone
+
+    UTC = timezone.utc
+
 from sbws.globals import fail_hard
 from sbws.util.filelock import DirectoryLock
 from sbws.util.timestamp import unixts_to_dt_obj
@@ -45,7 +53,7 @@ def gen_parser(sub):
 def _get_files_mtime_older_than(dname, days_delta, extensions):
     """Return file descriptors which modification time is older than days_delta
     and which extension is one of the extensions."""
-    today = datetime.utcfromtimestamp(time.time())
+    today = datetime.fromtimestamp(time.time(), UTC)
     oldest_day = today - timedelta(days=days_delta)
     # By default, `os.walk`` doesn't follow symlinks.
     # (https://docs.python.org/3/library/os.html#os.walk)
