@@ -158,13 +158,13 @@ def main(args, conf):
     if args.secs_recent:
         fresh_days = ceil(args.secs_recent / 24 / 60 / 60)
     elif scaling_method == TORFLOW_SCALING:
-        fresh_days = ceil(GENERATE_PERIOD / 24 / 60 / 60)
+        fresh_days = ceil(GENERATE_PERIOD / 24 / 60 / 60)  # 28
     else:
         fresh_days = conf.getint("general", "data_period")
     reset_bw_ipv4_changes = conf.getboolean("general", "reset_bw_ipv4_changes")
     reset_bw_ipv6_changes = conf.getboolean("general", "reset_bw_ipv6_changes")
     results = load_recent_results_in_datadir(
-        fresh_days,
+        fresh_days,  # 28
         datadir,
         on_changed_ipv4=reset_bw_ipv4_changes,
         on_changed_ipv6=reset_bw_ipv6_changes,
@@ -179,6 +179,9 @@ def main(args, conf):
     consensus_path = os.path.join(
         conf.getpath("tor", "datadir"), "cached-consensus"
     )
+    serverdescriptors_path = os.path.join(
+        conf.getpath("tor", "datadir"), "cached-descriptors"
+    )
     dirauth_nickname = conf["scanner"].get("dirauth_nickname", None)
     # Accept None as scanner_country to be compatible with older versions.
     scanner_country = conf["scanner"].get("country")
@@ -193,10 +196,11 @@ def main(args, conf):
         scaling_method,
         torflow_cap=args.torflow_bw_margin,
         round_digs=args.round_digs,
-        secs_recent=args.secs_recent,
+        secs_recent=args.secs_recent,  # None
         secs_away=args.secs_away,
         min_num=args.min_num,
         consensus_path=consensus_path,
+        serverdescriptors_path=serverdescriptors_path,
     )
     bw_file.write(valid_output)
     bw_file.info_stats
