@@ -1,4 +1,5 @@
-""" Measure the relays. """
+"""Measure the relays."""
+
 import concurrent.futures
 import logging
 import os
@@ -13,14 +14,15 @@ import uuid
 from argparse import ArgumentDefaultsHelpFormatter
 
 import requests
+import stem
 from stem.control import EventType
+from webclient import bytesgen
 
 import sbws.util.requests as requests_utils
 import sbws.util.stem as stem_utils
 from sbws.globals import (
     BWSCANNER_CC2,
     HTTP_GET_HEADERS,
-    HTTP_POST_INITIAL_SIZE,
     HTTP_POST_UL_KEY,
     SOCKET_TIMEOUT,
     fail_hard,
@@ -62,7 +64,6 @@ traceback."""
 
 
 def stop_threads(signal, frame, exit_code=0):
-    global rd
     log.debug("Stopping sbws.")
     # Avoid new threads to start.
     settings.set_end_event()
@@ -74,6 +75,7 @@ def stop_threads(signal, frame, exit_code=0):
 
 
 signal.signal(signal.SIGTERM, stop_threads)
+signal.signal(signal.SIGINT, stop_threads)
 
 
 def dumpstacks():
@@ -86,13 +88,13 @@ def dumpstacks():
         log.critical("Traceback: %s", "".join(traceback.format_stack(stack)))
 
 
-def sigint_handler():
+def sigint_handler(signum, frame):
     import pdb
 
     pdb.set_trace()
 
 
-signal.signal(signal.SIGINT, sigint_handler)
+signal.signal(signal.SIGUSR1, sigint_handler)
 
 
 def timed_recv_from_server(session, dest, byte_range):
@@ -102,11 +104,6 @@ def timed_recv_from_server(session, dest, byte_range):
 
     start_time = time.monotonic()
     HTTP_GET_HEADERS["Range"] = byte_range
-    # - response.elapsed "measures the time taken between sending the first
-    #   byte of the request and finishing parsing the headers.
-    #   It is therefore unaffected by consuming the response content"
-    #   If this mean that the content has arrived, elapsed could be used to
-    #   know the time it took.
     try:
         # headers are merged with the session ones, not overwritten.
         session.get(dest.url, headers=HTTP_GET_HEADERS, verify=dest.verify)
@@ -234,10 +231,6 @@ def upload_data(session, conf, dest, cont, circ_id):
     """
     log.debug("Uploading data...")
 
-    size = conf.getint("scanner", "http_post_initial_size")
-    # The data to upload is so far zeros.
-    data = bytearray(size)
-
     # Block other threads to attach an stream to the same circuit.
     # Otherwise, if there're measurer threads trying to attach other streams,
     # the controller will have several listener for the same event type
@@ -253,56 +246,48 @@ def upload_data(session, conf, dest, cont, circ_id):
         try:
             session.head(dest.url, verify=dest.verify)
         except requests.exceptions.RequestException as e:
-            dest.add_failure()
             return None, "Could not connect to {} over circ {} {}: {}".format(
                 dest.url, circ_id, stem_utils.circuit_str(cont, circ_id), e
             )
         finally:
             stem_utils.remove_event_listener(cont, listener)
 
-    try:
-        response = session.post(
-            dest.url,
-            files={conf.get("scanner", "payload_key"): data},
-            verify=dest.verify,
-            allow_redirects=False,
-        )
-    except requests.exceptions.RequestException as e:
-        dest.add_failure()
-        msg = "Could not connect to {} over circ {} {}: {}".format(
-            dest.url, circ_id, stem_utils.circuit_str(cont, circ_id), e
-        )
-        log.debug("%s: %s", msg, e)
-        return None, msg
-    except Exception as e:
-        dest.add_failure()
-        log.debug(e)
-        return None, e
-    finally:
-        log.debug("Finished uploading data.")
-
-    if response.status_code != requests.codes.ok:
-        dest.add_failure()
-        msg = (
-            "When sending HTTP POST to {}, we expected HTTP code {} "
-            "not {}".format(dest.url, requests.codes.ok, response.status_code)
-        )
+    chunk_generator = bytesgen.BytesGen(
+        chunk_bytes=conf.getint("scanner", "http_post_initial_bytes"),  # 1.5M
+        max_bytes=conf.getint("scanner", "max_download_size"),
+        min_bytes=conf.getint("scanner", "min_download_size"),
+        target_secs=conf.getint("scanner", "download_target"),
+        max_secs=conf.getint("scanner", "download_max"),
+    )
+    for chunk in chunk_generator:
+        try:
+            response = session.post(
+                dest.url,
+                files={conf.get("scanner", "payload_key"): chunk},
+                verify=dest.verify,
+                allow_redirects=False,
+            )
+        # Not returning cause other iterations might be successful
+        except (
+            requests.exceptions.ConnectionError,
+            requests.exceptions.ReadTimeout,
+        ) as e:
+            log.debug(e)
+            break
+        if not response.ok:
+            break
+        # response.elapsed "measures the time taken between sending the first
+        # byte of the request and finishing parsing the headers.
+        # It is therefore unaffected by consuming the response content"
+        # This mean that the payload has arrived to the server, so it can be
+        # used to know the time it took.
+        chunk_generator.set_delta_secs(response.elapsed.total_seconds())
+    results = chunk_generator.results
+    if not results:
+        msg = f"POST requests to {dest.url} failed, "
         log.debug(msg)
         return None, msg
-
-    dest.add_success()
-    time_elapsed = response.elapsed.total_seconds()
-    results = [{"duration": time_elapsed, "amount": size}]
-    log.debug("Time uploading %s bytes: %s seconds.", size, time_elapsed)
-    log.debug(
-        "POST response elapsed seconds: %s.",
-        response.elapsed.total_seconds(),
-    )
-    measured_bandwidth = size / time_elapsed
-    log.debug(
-        "Measured bandwidth: %s Bytes/seconds",
-        measured_bandwidth,
-    )
+    log.debug("Finished uploading data.")
     return results, None
 
 
@@ -420,6 +405,11 @@ def use_relay_as_entry(relay, rl, dest):
     """
     log.debug("Deciding whether to use the relay as entry or not.")
     relay_as_entry = True
+    # Try to measure relay as entry, always
+    log.debug(
+        "Use relay as entry." "Choose an exit that does have 2 in FlowCtrl"
+    )
+    return relay_as_entry
     if rl.is_consensus_cc_alg_2:
         log.debug("Congestion control enabled.")
         if rl.is_consensus_bwscanner_cc_gte_1:
@@ -472,6 +462,18 @@ def select_helper_candidates(relay, rl, dest, relay_as_entry=True):
     :rtype: list
 
     """
+    # If `relay_as_entry` is set, ignore the rest
+    if relay_as_entry:
+        candidates = rl.exits_with_2_in_flowctrl(dest.port)
+        # If relay is an exit,
+        if (
+            relay.is_exit_not_bad_allowing_port(dest.port)
+            and relay.has_2_in_flowctrl
+        ):
+            candidates = [
+                c for c in candidates if c.fingerprint != relay.fingerprint
+            ]
+        return candidates
     if rl.is_consensus_cc_alg_2:
         log.debug("Congestion control enabled.")
         if rl.is_consensus_bwscanner_cc_gte_1:
@@ -537,13 +539,14 @@ def select_helper_candidates(relay, rl, dest, relay_as_entry=True):
 
 def relay_update_xoff(relay, circ_id):
     # Check `XOFF_RECV/SENT`
-    relay.update_xoff_recv(
-        settings.stream_event[circ_id].pop("XOFF_RECV", None)
-    )
-    relay.update_xoff_sent(
-        settings.stream_event[circ_id].pop("XOFF_SENT", None)
-    )
-    settings.stream_event.pop(circ_id)
+    if settings.stream_event.get(circ_id, None):
+        relay.update_xoff_recv(
+            settings.stream_event[circ_id].pop("XOFF_RECV", None)
+        )
+        relay.update_xoff_sent(
+            settings.stream_event[circ_id].pop("XOFF_SENT", None)
+        )
+        settings.stream_event.pop(circ_id)
 
 
 def measure_relay(args, conf, destinations, cb, rl, relay):
@@ -634,7 +637,7 @@ def measure_relay(args, conf, destinations, cb, rl, relay):
         relay.nickname,
     )
 
-    if rl.is_consensus_bwscanner_cc_2:
+    if rl.is_consensus_bwscanner_cc_2(conf.getboolean("scanner", "upload")):
         # 40130: Upload data instead of downloading it.
         bw_results, reason = upload_data(s, conf, dest, cb.controller, circ_id)
     else:
@@ -818,9 +821,11 @@ def _should_keep_result(did_request_maximum, result_time, download_times):
     log.debug(
         "Not keeping result time %f.%s",
         result_time,
-        ""
-        if not did_request_maximum
-        else " We requested the maximum " "amount allowed.",
+        (
+            ""
+            if not did_request_maximum
+            else " We requested the maximum " "amount allowed."
+        ),
     )
     return False
 
@@ -872,20 +877,14 @@ def log_measurement_exception(target, exception):
     log.warning(FILLUP_TICKET_MSG)
     # To print the traceback that happened in the thread, not here in
     # the main process.
-    log.warning(
-        "".join(
-            traceback.format_exception(
-                type(exception), exception, exception.__traceback__
-            )
-        )
-    )
+    log.warning(traceback.format_exc())
     log.debug(
-        "".join(
-            target.fingerprint,
-            target.nickname,
-            traceback.format_exception(
-                type(exception), exception, exception.__traceback__
-            ),
+        ", ".join(
+            [
+                target.fingerprint,
+                target.nickname,
+                traceback.format_exc(),
+            ]
         )
     )
 
@@ -984,7 +983,12 @@ def main_loop(
             loop_tdelta,
         )
         # In a testing network, exit after first loop
-        if controller.get_conf("TestingTorNetwork") == "1":
+        try:
+            test_net = controller.get_conf("TestingTorNetwork")
+        except stem.SocketClosed:
+            # If the socket is already closed, assume testnet too
+            test_net = "1"
+        if test_net == "1":
             log.info("In a testing network, exiting after the first loop.")
             # Threads should be closed nicely in some refactor
             stop_threads(signal.SIGTERM, None)
@@ -1109,7 +1113,7 @@ def run_speedtest(args, conf):
     )
     # To do not have to pass args and conf to RelayList, pass an extra
     # argument with the data_period
-    measurements_period = conf.getint("general", "data_period")
+    measurements_period = conf.getint("general", "data_period")  # 5
     rl = RelayList(args, conf, controller, measurements_period, state)
     cb = CB(args, conf, controller, rl)
     rd = ResultDump(args, conf)
@@ -1121,9 +1125,6 @@ def run_speedtest(args, conf):
         fail_hard(error_msg)
     try:
         main_loop(args, conf, controller, rl, cb, rd, rp, destinations)
-    except KeyboardInterrupt:
-        log.info("Interrupted by the user.")
-        dumpstacks()
     except Exception as e:
         log.exception(e)
         dumpstacks()
@@ -1158,7 +1159,6 @@ def main(args, conf):
     # For now, no need to add these variables as config file options or args.
     print("conf", conf)
     conf["scanner"]["payload_key"] = str(HTTP_POST_UL_KEY)
-    conf["scanner"]["http_post_initial_size"] = str(HTTP_POST_INITIAL_SIZE)
 
     state = State(conf.getpath("paths", "state_fname"))
     state["scanner_started"] = now_isodt_str()
