@@ -1,6 +1,13 @@
 import logging
 from argparse import ArgumentDefaultsHelpFormatter
 from datetime import datetime, timedelta
+
+try:
+    from datetime import UTC
+except ImportError:
+    from datetime import timezone
+
+    UTC = timezone.utc
 from statistics import mean
 
 from sbws.lib.resultdump import (
@@ -97,7 +104,7 @@ def _print_averages(data):
 
 def _results_into_bandwidths(results, limit=5):
     """
-    For all the given resutls, extract their download statistics and normalize
+    For all the given results, extract their download statistics and normalize
     them into bytes/second bandwidths.
 
     :param list results: list of :class:`sbws.list.resultdump.ResultSuccess`
@@ -132,9 +139,9 @@ def print_stats(args, data):
     )
     first_time = min([r.time for r in results])
     last_time = max([r.time for r in results])
-    first = datetime.utcfromtimestamp(first_time)
+    first = datetime.fromtimestamp(first_time, UTC)
     first = first - timedelta(microseconds=first.microsecond)
-    last = datetime.utcfromtimestamp(last_time)
+    last = datetime.fromtimestamp(last_time, UTC)
     last = last - timedelta(microseconds=last.microsecond)
     duration = last - first
     print(len(data), "relays have recent results")
@@ -187,7 +194,7 @@ def main(args, conf):
 
     datadir = conf.getpath("paths", "datadir")
 
-    fresh_days = conf.getint("general", "data_period")
+    fresh_days = conf.getint("general", "data_period")  # 5
     results = load_recent_results_in_datadir(
         fresh_days, datadir, success_only=False
     )
