@@ -1,8 +1,15 @@
 import copy
 import logging
 import random
+import threading
 from datetime import datetime, timedelta
-from threading import Lock
+
+try:
+    from datetime import UTC
+except ImportError:
+    from datetime import timezone
+
+    UTC = timezone.utc
 
 from stem import ControllerError, DescriptorUnavailable, Flag
 
@@ -14,10 +21,12 @@ from ..globals import (
 )
 from ..util import timestamps
 
+RL_LOCK = threading.RLock()
+
 log = logging.getLogger(__name__)
 
 
-def valid_after_from_network_statuses(network_statuses):
+def valid_after_from_network_statuses(network_statuses) -> datetime:
     """Obtain the consensus Valid-After datetime from the ``document``
     attribute of a ``stem.descriptor.RouterStatusEntryV3``.
 
@@ -30,8 +39,8 @@ def valid_after_from_network_statuses(network_statuses):
         if document:
             valid_after = getattr(document, "valid_after", None)
             if valid_after:
-                return valid_after
-    return datetime.utcnow().replace(microsecond=0)
+                return valid_after.replace(tzinfo=UTC)
+    return datetime.now(UTC).replace(microsecond=0)
 
 
 class Relay:
@@ -271,7 +280,11 @@ class Relay:
 
         It is call from :func:`~sbws.core.scaner.main_loop`.
         """
-        self.relay_recent_measurement_attempt.update()
+        log.debug("Incrementing `relay_recent_measurement_attempt`.")
+        with RL_LOCK:
+            # log.debug("Acquired RL lock")
+            self.relay_recent_measurement_attempt.update()
+        # log.debug("Released RL lock")
 
     @property
     def relay_recent_measurement_attempt_count(self):
@@ -320,7 +333,6 @@ class RelayList:
     ):
         self._controller = controller
         self.rng = random.SystemRandom()
-        self._refresh_lock = Lock()
         # To track all the consensus seen.
         self._recent_consensus = timestamps.DateTimeSeq(
             [], MAX_RECENT_CONSENSUS_COUNT, state, "recent_consensus"
@@ -344,7 +356,7 @@ class RelayList:
 
     def _need_refresh(self):
         # New consensuses happen every hour.
-        return datetime.utcnow() >= self.last_consensus_timestamp + timedelta(
+        return datetime.now(UTC) >= self.last_consensus_timestamp + timedelta(
             seconds=60 * 60
         )
 
@@ -362,9 +374,9 @@ class RelayList:
                 "We need to refresh our list of relays. "
                 "Going to wait for lock."
             )
-            # Whelp we couldn't just get the list of relays because the list is
+            # We couldn't just get the list of relays because the list is
             # stale. Wait for the lock so we can refresh it.
-            with self._refresh_lock:
+            with RL_LOCK:
                 log.debug(
                     "We got the lock. Now to see if we still "
                     "need to refresh."
@@ -449,54 +461,59 @@ class RelayList:
         # consensus and have not been seen in the last consensuses either.
         num_old_relays = 0
 
-        relays = copy.deepcopy(self._relays)
-        for r in relays:
-            if r.fingerprint in new_relays_dict.keys():
-                # If a relay in the previous consensus and is in the current
-                # one, update its timestamp, router status and descriptor.
-                fp = r.fingerprint
-                # new_relays_dict[fp] is the router status.
-                r.update_router_status(new_relays_dict[fp])
-                r.update_relay_in_recent_consensus(timestamp)
-                try:
-                    descriptor = c.get_server_descriptor(fp, default=None)
-                except (DescriptorUnavailable, ControllerError) as e:
-                    log.exception("Exception trying to get desc %s", e)
-                r.update_server_descriptor(descriptor)
-                # Add it to the new list of relays.
+        with RL_LOCK:
+            # log.debug("Acquired RL lock")
+            relays = copy.deepcopy(self._relays)
+            for r in relays:
+                if r.fingerprint in new_relays_dict.keys():
+                    # If a relay in the previous consensus and is in the current
+                    # one, update its timestamp, router status and descriptor.
+                    fp = r.fingerprint
+                    # new_relays_dict[fp] is the router status.
+                    r.update_router_status(new_relays_dict[fp])
+                    r.update_relay_in_recent_consensus(timestamp)
+                    try:
+                        descriptor = c.get_server_descriptor(fp, default=None)
+                    except (DescriptorUnavailable, ControllerError) as e:
+                        log.exception("Exception trying to get desc %s", e)
+                    r.update_server_descriptor(descriptor)
+                    # Add it to the new list of relays.
+                    new_relays.append(r)
+                    # And remove it from the new consensus dict, as it has
+                    # already added to the new list.
+                    new_relays_dict.pop(fp)
+
+                # In #30727, the relay that is not in the current consensus but is
+                # not "old", was added to the new list of relays too.
+                # In #40037 we think it should not be measured, as it might cause
+                # many circuit errors. It's already added to the generator.
+                # Otherwise, don't add it to the new list of relays.
+                # For debugging, count the old relays that will be discarded.
+                else:
+                    num_old_relays += 1
+
+            # Finally, add the relays that were not in the previous consensus
+            for fp, ns in new_relays_dict.items():
+                r = Relay(ns.fingerprint, c, ns=ns, timestamp=timestamp)
                 new_relays.append(r)
-                # And remove it from the new consensus dict, as it has
-                # already added to the new list.
-                new_relays_dict.pop(fp)
 
-            # In #30727, the relay that is not in the current consensus but is
-            # not "old", was added to the new list of relays too.
-            # In #40037 we think it should not be measured, as it might cause
-            # many circuit errors. It's already added to the generator.
-            # Otherwise, don't add it to the new list of relays.
-            # For debugging, count the old relays that will be discarded.
-            else:
-                num_old_relays += 1
-
-        # Finally, add the relays that were not in the previous consensus
-        for fp, ns in new_relays_dict.items():
-            r = Relay(ns.fingerprint, c, ns=ns, timestamp=timestamp)
-            new_relays.append(r)
-
-        days = self._measurements_period / (60 * 60 * 24)
-        log.debug(
-            "Previous number of relays being measured %d", len(self._relays)
-        )
-        log.debug(
-            "Number of relays not in the in the consensus in the last "
-            "%d days: %d.",
-            days,
-            num_old_relays,
-        )
-        log.debug(
-            "Number of relays to measure with the current consensus: " "%d",
-            len(new_relays),
-        )
+            days = self._measurements_period
+            log.debug(
+                "Previous number of relays being measured %d",
+                len(self._relays),
+            )
+            log.debug(
+                "Number of relays not in the in the consensus in the last "
+                "%d days: %d.",
+                days,
+                num_old_relays,
+            )
+            log.debug(
+                "Number of relays to measure with the current consensus: "
+                "%d",
+                len(new_relays),
+            )
+        # log.debug("Released RL lock")
         return new_relays
 
     def _refresh(self):
@@ -505,7 +522,7 @@ class RelayList:
 
         log.info(
             "Number of consensuses obtained in the last %s days: %s.",
-            int(self._measurements_period / 24 / 60 / 60),
+            int(self._measurements_period),
             self.recent_consensus_count,
         )
 
@@ -636,10 +653,15 @@ class RelayList:
         )
         return False
 
-    @property
-    def is_consensus_bwscanner_cc_2(self):
+    def is_consensus_bwscanner_cc_2(self, force_upload=False):
         """Return True if the consensus document has a value of 2 in
         the `bwscanner_cc` field."""
+        if force_upload:
+            log.info(
+                "Forcing upload, independently of `bwscanner_cc` consensus "
+                "parameter."
+            )
+            return True
         if (
             self.consensus_params_dict
             and self.consensus_params_dict.get("bwscanner_cc", 0) == 2
