@@ -1,15 +1,26 @@
+import gc
 import json
 import logging
 import os
 import time
 from datetime import datetime, timedelta
+
+try:
+    from datetime import UTC
+except ImportError:
+    from datetime import timezone
+
+    UTC = timezone.utc
 from enum import Enum
 from glob import glob
 from queue import Empty, Queue
 from threading import RLock, Thread
 
+import psutil
+
 from sbws.globals import RESULT_VERSION, fail_hard
 from sbws.util.filelock import DirectoryLock
+from sbws.util.fs import atomic_append_line
 from sbws.util.json import CustomDecoder, CustomEncoder
 
 from .. import settings
@@ -72,9 +83,11 @@ def load_result_file(fname, success_only=False):
 def trim_results(fresh_days, result_dict):
     """Given a result dictionary, remove all Results that are no longer valid
     and return the new dictionary"""
-    data_period = fresh_days * 24 * 60 * 60
+    data_period = fresh_days * 24 * 60 * 60  # Either 5 or 28 days
     oldest_allowed = time.time() - data_period
     out_results = {}
+    memory_used = psutil.virtual_memory().used
+    log.debug("Before trimming, memory used: %s", memory_used)
     for fp in result_dict:
         for result in result_dict[fp]:
             if result.time >= oldest_allowed:
@@ -84,6 +97,11 @@ def trim_results(fresh_days, result_dict):
     num_in = sum([len(result_dict[fp]) for fp in result_dict])
     num_out = sum([len(out_results[fp]) for fp in out_results])
     log.debug("Keeping %d/%d results after removing old ones", num_out, num_in)
+    # Try to free memory from old measurements.
+    del result_dict
+    # gc.collect()
+    memory_used = psutil.virtual_memory().used
+    log.debug("After trimming, memory used: %s", memory_used)
     return out_results
 
 
@@ -132,7 +150,7 @@ def trim_results_ip_changed(
 
 
 def load_recent_results_in_datadir(
-    fresh_days,
+    fresh_days,  # Either 5 or 28 days
     datadir,
     success_only=False,
     on_changed_ipv4=False,
@@ -144,8 +162,8 @@ def load_recent_results_in_datadir(
     # Inform the results are being loaded, since it takes some seconds.
     log.info("Reading and processing previous measurements.")
     results = {}
-    today = datetime.utcfromtimestamp(time.time())
-    data_period = fresh_days + 2
+    today = datetime.fromtimestamp(time.time(), UTC)
+    data_period = fresh_days + 2  # either 7 or 30 days
     oldest_day = today - timedelta(days=data_period)
     working_day = oldest_day
     while working_day <= today:
@@ -164,7 +182,7 @@ def load_recent_results_in_datadir(
                 )
                 results = merge_result_dicts(results, new_results)
         working_day += timedelta(days=1)
-    results = trim_results(fresh_days, results)
+    results = trim_results(fresh_days, results)  # either 5 or 28 days
     # in time fresh days is possible that a relay changed ip,
     # if that's the case, keep only the results for the last ip
     results = trim_results_ip_changed(
@@ -185,14 +203,12 @@ def load_recent_results_in_datadir(
 
 def write_result_to_datadir(result, datadir):
     """Can be called from any thread"""
-    dt = datetime.utcfromtimestamp(result.time)
+    dt = datetime.fromtimestamp(result.time, UTC)
     ext = ".txt"
     result_fname = os.path.join(datadir, "{}{}".format(dt.date(), ext))
     try:
-        with DirectoryLock(datadir):
-            log.debug("Writing a result to %s", result_fname)
-            with open(result_fname, "at") as fd:
-                fd.write("{}\n".format(str(result)))
+        log.debug("Writing a result to %s", result_fname)
+        atomic_append_line(f"{str(result)}\n", result_fname)
     # Catch any exception writing.
     except Exception as e:
         log.error(
@@ -861,7 +877,7 @@ class ResultDump:
 
     def __init__(self, args, conf):
         self.conf = conf
-        self.fresh_days = conf.getint("general", "data_period")
+        self.fresh_days = conf.getint("general", "data_period")  # 5 days
         self.datadir = conf.getpath("paths", "datadir")
         self.data = {}
         self.data_lock = RLock()
@@ -879,7 +895,7 @@ class ResultDump:
             if fp not in self.data:
                 self.data[fp] = []
             self.data[fp].append(result)
-            self.data = trim_results(self.fresh_days, self.data)
+            self.data = trim_results(self.fresh_days, self.data)  # 5 days
             # Not calling trim_results_ip_changed here to do not remove
             # the results for a relay that has changed address.
             # It will be called when loading the results to generate a v3bw
@@ -961,7 +977,7 @@ class ResultDump:
         """
         with self.data_lock:
             self.data = load_recent_results_in_datadir(
-                self.fresh_days, self.datadir
+                self.fresh_days, self.datadir  # 5 days
             )
         while not (settings.end_event.is_set() and self.queue.empty()):
             try:
