@@ -466,7 +466,7 @@ class V3BWHeader(object):
             index_terminator = lines.index(TERMINATOR)
         except ValueError:
             # is not a bw file or is v100
-            log.warn("Terminator is not in lines")
+            log.warning("Terminator is not in lines")
             return None
         ts = lines[0]
         kwargs = dict(
@@ -724,6 +724,7 @@ class V3BWLine(object):
         secs_away=None,
         min_num=0,
         router_statuses_d=None,
+        server_descriptors_d=None,
     ):
         """Convert sbws results to relays' Bandwidth Lines
 
@@ -821,9 +822,9 @@ class V3BWLine(object):
         number_excluded_error = len(results) - len(success_results)
         if number_excluded_error > 0:
             # then the number of error results is the number of results
-            kwargs[
-                "relay_recent_measurements_excluded_error_count"
-            ] = number_excluded_error
+            kwargs["relay_recent_measurements_excluded_error_count"] = (
+                number_excluded_error
+            )
         if not success_results:
             exclusion_reason = "recent_measurements_excluded_error_count"
             return (cls(node_id, 1, **kwargs), exclusion_reason)
@@ -831,9 +832,9 @@ class V3BWLine(object):
         results_away = cls.results_away_each_other(success_results, secs_away)
         number_excluded_near = len(success_results) - len(results_away)
         if number_excluded_near > 0:
-            kwargs[
-                "relay_recent_measurements_excluded_near_count"
-            ] = number_excluded_near
+            kwargs["relay_recent_measurements_excluded_near_count"] = (
+                number_excluded_near
+            )
         if not results_away:
             exclusion_reason = "recent_measurements_excluded_near_count"
             return (cls(node_id, 1, **kwargs), exclusion_reason)
@@ -843,9 +844,9 @@ class V3BWLine(object):
         results_recent = cls.results_recent_than(results_away, secs_recent)
         number_excluded_old = len(results_away) - len(results_recent)
         if number_excluded_old > 0:
-            kwargs[
-                "relay_recent_measurements_excluded_old_count"
-            ] = number_excluded_old
+            kwargs["relay_recent_measurements_excluded_old_count"] = (
+                number_excluded_old
+            )
         if not results_recent:
             exclusion_reason = "recent_measurements_excluded_old_count"
             return (cls(node_id, 1, **kwargs), exclusion_reason)
@@ -860,10 +861,13 @@ class V3BWLine(object):
 
         # Use the last consensus if available, since the results' consensus
         # values come from the moment the measurement was made.
-        if router_statuses_d and node_id in router_statuses_d:
-            consensus_bandwidth = router_statuses_d[node_id].bandwidth * 1000
+        fingerprint = node_id.replace("$", "")
+        if router_statuses_d and fingerprint in router_statuses_d:
+            consensus_bandwidth = (
+                router_statuses_d[fingerprint].bandwidth * 1000
+            )
             consensus_bandwidth_is_unmeasured = router_statuses_d[
-                node_id
+                fingerprint
             ].is_unmeasured
         else:
             consensus_bandwidth = cls.consensus_bandwidth_from_results(
@@ -874,15 +878,34 @@ class V3BWLine(object):
                     results_recent
                 )
             )
-        # If there is no last observed bandwidth, there won't be mean either.
-        desc_bw_obs_last = cls.desc_bw_obs_last_from_results(results_recent)
+        # Take last server descriptors from cache
+        if server_descriptors_d:
+            if fingerprint in server_descriptors_d:
+                desc_bw_obs_last = server_descriptors_d[
+                    fingerprint
+                ].observed_bandwidth
+                desc_bw_avg = server_descriptors_d[
+                    fingerprint
+                ].average_bandwidth
+                desc_bw_bur = server_descriptors_d[fingerprint].burst_bandwidth
+            else:
+                # If there is no last observed bandwidth, there won't be mean
+                # either.in the result structure here
+                desc_bw_obs_last = None
+        # For the cases when there isn't cached descriptors like tests.
+        else:
+            desc_bw_obs_last = cls.desc_bw_obs_last_from_results(
+                results_recent
+            )
+            desc_bw_avg = cls.desc_bw_avg_from_results(results_recent)
+            desc_bw_bur = cls.desc_bw_bur_from_results(results_recent)
 
         # Exclude also relays without observed bandwidth, since they can't be
         # scaled
         if desc_bw_obs_last is None:
             # This reason is not counted, not added in the file, but it will
             # have vote = 0
-            return (cls(node_id, 1), "no_observed_bw")
+            return (cls(node_id, 1, **kwargs), "no_observed_bw")
 
         # For any line not excluded, do not include vote and unmeasured
         # KeyValues
@@ -899,12 +922,12 @@ class V3BWLine(object):
         kwargs["bw_mean"] = cls.bw_mean_from_results(results_recent)
         kwargs["bw_filt"] = scaling.bw_filt(bw_measurements)
         kwargs["bw_median"] = cls.bw_median_from_results(results_recent)
-        kwargs["desc_bw_avg"] = cls.desc_bw_avg_from_results(results_recent)
-        kwargs["desc_bw_bur"] = cls.desc_bw_bur_from_results(results_recent)
+        kwargs["desc_bw_avg"] = desc_bw_avg
+        kwargs["desc_bw_bur"] = desc_bw_bur
         kwargs["consensus_bandwidth"] = consensus_bandwidth
-        kwargs[
-            "consensus_bandwidth_is_unmeasured"
-        ] = consensus_bandwidth_is_unmeasured
+        kwargs["consensus_bandwidth_is_unmeasured"] = (
+            consensus_bandwidth_is_unmeasured
+        )
         kwargs["desc_bw_obs_last"] = desc_bw_obs_last
         kwargs["desc_bw_obs_mean"] = cls.desc_bw_obs_mean_from_results(
             results_recent
@@ -1100,7 +1123,7 @@ class V3BWLine(object):
         if len(bw_line_str) > BW_LINE_SIZE:
             # if this is the case, probably there are too many KeyValues,
             # or the limit needs to be changed in Tor
-            log.warn(
+            log.warning(
                 "The bandwidth line %s is longer than %s",
                 len(bw_line_str),
                 BW_LINE_SIZE,
@@ -1142,6 +1165,7 @@ class V3BWFile(object):
         secs_away=None,
         min_num=0,
         consensus_path=None,
+        serverdescriptors_path=None,
         max_bw_diff_perc=MAX_BW_DIFF_PERC,
         reverse=False,
     ):
@@ -1177,6 +1201,9 @@ class V3BWFile(object):
         number_consensus_relays = cls.read_number_consensus_relays(
             consensus_path
         )
+        server_descriptors_d = cls.read_server_descriptors(
+            serverdescriptors_path
+        )
         state = State(state_fpath)
 
         # Create a dictionary with the number of relays excluded by any of the
@@ -1190,7 +1217,12 @@ class V3BWFile(object):
         for fp, values in results.items():
             # log.debug("Relay fp %s", fp)
             line, reason = V3BWLine.from_results(
-                values, secs_recent, secs_away, min_num, router_statuses_d
+                values,
+                secs_recent,
+                secs_away,
+                min_num,
+                router_statuses_d,
+                server_descriptors_d,
             )
             # If there is no reason it means the line will not be excluded.
             if not reason:
@@ -1523,6 +1555,25 @@ class V3BWFile(object):
             )
         return router_statuses_d
 
+    @staticmethod
+    def read_server_descriptors(serverdescriptors_path):
+        """Read the server descriptors from the cached descriptors file."""
+        server_descriptors_d = None
+        try:
+            server_descriptors_d = dict(
+                [
+                    (r.fingerprint, r)
+                    for r in parse_file(serverdescriptors_path)
+                ]
+            )
+        except (FileNotFoundError, AttributeError):
+            log.warning(
+                "It is not possible to obtain the last server descriptors "
+                "cache file %s.",
+                serverdescriptors_path,
+            )
+        return server_descriptors_d
+
     @staticmethod
     def measured_progress_stats(
         num_bw_lines, number_consensus_relays, min_perc_reached_before
