@@ -62,7 +62,12 @@ def _get_default_config():
 
 def _obtain_user_conf_path():
     if os.environ.get("SUPERVISED") == "1":
+        print(
+            "Running SUPERVISED with configuration file: ",
+            SUPERVISED_USER_CONFIG_PATH,
+        )
         return SUPERVISED_USER_CONFIG_PATH
+    print("Running not SUPERVISED with configuration file: ", USER_CONFIG_PATH)
     return USER_CONFIG_PATH
 
 
@@ -161,15 +166,15 @@ def configure_logging(args, conf):
         # 'sbws' failing that.
         dname = conf.getpath("paths", "log_dname")
         fname = os.path.join(dname, "{}.log".format(args.command or "sbws"))
-        # The second argument is the file mode, and it should be left alone
-        mode = "a"
-        # The third is the maximum file size (in bytes) each log file should be
-        max_bytes = conf.getint("logging", "to_file_max_bytes")
+        # The second argument is the when
+        when = conf.get("logging", "to_file_when")
+        # The third is the interval
+        interval = conf.getint("logging", "to_file_interval")
         # And the forth is the number of backups to keep
         num_backups = conf.getint("logging", "to_file_num_backups")
         # Now store those things as a string in the config. So dumb.
         conf["handler_to_file"]["args"] = str(
-            (fname, mode, max_bytes, num_backups)
+            (fname, when, interval, num_backups)
         )
     # Set some stuff that needs config parser's interpolation
     conf["formatter_to_file"]["format"] = conf["logging"]["to_file_format"]
@@ -224,6 +229,7 @@ def _validate_cleanup(conf):
         "data_files_delete_after_days": {"minimum": 1, "maximum": None},
         "v3bw_files_compress_after_days": {"minimum": 1, "maximum": None},
         "v3bw_files_delete_after_days": {"minimum": 1, "maximum": None},
+        "log_files_compress_after_days": {"minimum": 1, "maximum": None},
     }
     all_valid_keys = list(ints.keys())
     errors.extend(_validate_section_keys(conf, sec, all_valid_keys, err_tmpl))
@@ -261,6 +267,7 @@ def _obtain_sbws_home(conf):
     # No need for .sbws when this is the default home
     if sbws_home == "/var/lib/sbws/.sbws":
         conf["paths"]["sbws_home"] = os.path.dirname(sbws_home)
+    print("sbws data path: ", conf["paths"]["sbws_home"])
 
 
 def _obtain_run_dpath(conf):
@@ -356,6 +363,7 @@ def _validate_scanner(conf):
         "measurement_threads": {"minimum": 1, "maximum": None},
         "min_download_size": {"minimum": 1, "maximum": None},
         "max_download_size": {"minimum": 1, "maximum": None},
+        "http_post_initial_bytes": {"minimum": 1, "maximum": None},
     }
     floats = {
         "download_toofast": {"minimum": 0.001, "maximum": None},
@@ -366,7 +374,7 @@ def _validate_scanner(conf):
     all_valid_keys = (
         list(ints.keys())
         + list(floats.keys())
-        + ["nickname", "country", "dirauth_nickname"]
+        + ["nickname", "country", "dirauth_nickname", "upload"]
     )
     errors.extend(_validate_section_keys(conf, sec, all_valid_keys, err_tmpl))
     errors.extend(_validate_section_ints(conf, sec, ints, err_tmpl))
@@ -443,10 +451,11 @@ def _validate_logging(conf):
         "to_syslog": {},
     }
     ints = {
-        "to_file_max_bytes": {"minimum": 0, "maximum": None},
         "to_file_num_backups": {"minimum": 0, "maximum": None},
+        "to_file_interval": {"minimum": 0, "maximum": None},
     }
     unvalidated = [
+        "to_file_when",
         "format",
         "to_file_format",
         "to_stdout_format",
@@ -496,7 +505,6 @@ def _validate_destinations(conf):
     all_valid_keys = list(urls.keys()) + [
         "verify",
         "country",
-        "max_num_failures",
     ]
     for sec in dest_sections:
         if sec not in conf:
@@ -511,7 +519,7 @@ def _validate_destinations(conf):
                 sec,
                 all_valid_keys,
                 err_tmpl,
-                allow_missing=["verify", "max_num_failures"],
+                allow_missing=["verify"],
             )
         )
         errors.extend(_validate_section_urls(conf, sec, urls, err_tmpl))
