@@ -1,27 +1,34 @@
 """Util functions to convert between timestamp formats"""
+
 from datetime import datetime, timedelta
 
+try:
+    from datetime import UTC
+except ImportError:
+    from datetime import timezone
+
+    UTC = timezone.utc
+
 from ..globals import MEASUREMENTS_PERIOD
 
 
-def dt_obj_to_isodt_str(dt):
+def dt_obj_to_isodt_str(dt) -> str:
     """
-    Convert datetime object to ISO 8601 string.
+    Convert datetime object to ISO 8601 string without timezone.
 
     :param datetime dt: datetime object in UTC timezone
     :returns: ISO 8601 string
     """
-    # Using naive datetime object without timezone, assumed utc
-    return dt.replace(microsecond=0).isoformat()
+    return dt.replace(microsecond=0).replace(tzinfo=None).isoformat()
 
 
-def isostr_to_dt_obj(isostr):
-    return datetime.strptime(isostr, "%Y-%m-%dT%H:%M:%S")
+def isostr_to_dt_obj(isostr) -> datetime:
+    return datetime.strptime(isostr, "%Y-%m-%dT%H:%M:%S").replace(tzinfo=UTC)
 
 
-def unixts_to_dt_obj(unixts):
+def unixts_to_dt_obj(unixts) -> datetime:
     """
-    Convert unix timestamp to naive datetime object in UTC time zone.
+    Convert unix timestamp to datetime object in UTC time zone.
 
     :param float/int/str unixts: unix timestamp
     :returns: datetime object in UTC timezone
@@ -33,10 +40,10 @@ def unixts_to_dt_obj(unixts):
             unixts = float(unixts)
     if isinstance(unixts, float):
         unixts = int(unixts)
-    return datetime.utcfromtimestamp(unixts)
+    return datetime.fromtimestamp(unixts, UTC)
 
 
-def unixts_to_isodt_str(unixts):
+def unixts_to_isodt_str(unixts) -> str:
     """
     Convert unix timestamp to ISO 8601 string in UTC time zone.
 
@@ -46,26 +53,26 @@ def unixts_to_isodt_str(unixts):
     return dt_obj_to_isodt_str(unixts_to_dt_obj(unixts))
 
 
-def now_unixts():
-    return datetime.utcnow().timestamp()
+def now_unixts() -> float:
+    return datetime.now(UTC).timestamp()
 
 
-def now_isodt_str():
+def now_isodt_str() -> str:
     """Return datetime now as ISO 8601 string in UTC time zone."""
-    return dt_obj_to_isodt_str(datetime.utcnow())
+    return dt_obj_to_isodt_str(datetime.now(UTC))
 
 
-def now_fname():
+def now_fname() -> str:
     """
     Return now timestamp in UTC formatted as %Y%m%d_%H%M%S string for file
     names.
 
     :returns: now timestamp in UTC formatted as %Y%m%d_%H%M%S string
     """
-    return datetime.utcnow().strftime("%Y%m%d_%H%M%S")
+    return datetime.now(UTC).strftime("%Y%m%d_%H%M%S")
 
 
-def unixts_to_str(unixts):
+def unixts_to_str(unixts) -> str:
     """Convert unix timestamp integer or float to string"""
     # even if it is only converting to str, ensure that input is nothing else
     # than int or float
@@ -87,5 +94,5 @@ def is_old(timestamp, measurements_period=MEASUREMENTS_PERIOD):
             # This will raise an exception if the type is not int or float or
             # is not actually a timestamp
             timestamp = unixts_to_dt_obj(timestamp)
-    oldest_date = datetime.utcnow() - timedelta(seconds=measurements_period)
+    oldest_date = datetime.now(UTC) - timedelta(seconds=measurements_period)
     return timestamp < oldest_date
