@@ -29,7 +29,7 @@ from sbws.lib.v3bwfile import (
     num_results_of_type,
     round_sig_dig,
 )
-from sbws.util.state import CustomDecoder
+from sbws.util.json import CustomDecoder
 from sbws.util.timestamp import now_fname, now_isodt_str, now_unixts
 
 timestamp = 1523974147
