@@ -1,6 +1,13 @@
 # -*- coding: utf-8 -*-
 """Test timestamp conversion util functions"""
-from datetime import datetime, timedelta, timezone
+from datetime import datetime, timedelta
+
+try:
+    from datetime import UTC
+except ImportError:
+    from datetime import timezone
+
+    UTC = timezone.utc
 
 from sbws.util.timestamp import (
     dt_obj_to_isodt_str,
@@ -11,8 +18,8 @@ from sbws.util.timestamp import (
 )
 
 isodt_str = "2018-05-23T12:55:04"
-dt_obj = datetime.strptime(isodt_str, "%Y-%m-%dT%H:%M:%S")
-unixts = int(dt_obj.replace(tzinfo=timezone.utc).timestamp())
+dt_obj = datetime.strptime(isodt_str, "%Y-%m-%dT%H:%M:%S").replace(tzinfo=UTC)
+unixts = int(dt_obj.timestamp())
 
 
 def test_dt_obj_to_isodt_str():
@@ -34,10 +41,10 @@ def test_unixts_to_str():
 def test_is_old():
     # Since this timestamp is generated a few microseconds before checking
     # the oldest timestamp, it will be old.
-    old_timestamp = datetime.utcnow() - timedelta(days=5)
+    old_timestamp = datetime.now(UTC) - timedelta(days=5)
     assert is_old(old_timestamp)
     # A recent timestamp should be at least 1 second newer that the oldest
     recent_timestamp = (
-        datetime.utcnow() - timedelta(days=5) + timedelta(seconds=1)
+        datetime.now(UTC) - timedelta(days=5) + timedelta(seconds=1)
     )
     assert not is_old(recent_timestamp)
