@@ -2,12 +2,19 @@
 
 from datetime import datetime, timedelta
 
+try:
+    from datetime import UTC
+except ImportError:
+    from datetime import timezone
+
+    UTC = timezone.utc
+
 from sbws.util.state import State
 from sbws.util.timestamps import DateTimeIntSeq, DateTimeSeq
 
 
 def test_update_datetime_seq(conf):
-    now = datetime.utcnow().replace(microsecond=0)
+    now = datetime.now(UTC).replace(microsecond=0)
     state = State(conf["paths"]["state_fpath"])
     # Create a list of 6 datetimes that started 6 days in the past.
     dts = [now - timedelta(days=x) for x in range(6, 0, -1)]
@@ -23,7 +30,7 @@ def test_update_datetime_seq(conf):
 
 
 def test_update_datetime_int_seq(conf):
-    now = datetime.utcnow().replace(microsecond=0)
+    now = datetime.now(UTC).replace(microsecond=0)
     state = State(conf["paths"]["state_fpath"])
     # Create a list of 6 datetimes that started 6 days in the past.
     dts = [[now - timedelta(days=x), 2] for x in range(6, 0, -1)]
@@ -44,13 +51,13 @@ def test_update_datetime_int_seq(conf):
 def test_last_datetime_seq(conf):
     dt_seq = DateTimeSeq([])
     new_dts = dt_seq.last()
-    assert new_dts == datetime.utcnow().replace(microsecond=0) - timedelta(
+    assert new_dts == datetime.now(UTC).replace(microsecond=0) - timedelta(
         hours=1
     )
 
 
 def test_create_list_datetime_seq(conf):
-    now = datetime.utcnow().replace(microsecond=0)
+    now = datetime.now(UTC).replace(microsecond=0)
     # Create a list of 6 datetimes that started 6 days in the past.
     dts = [now - timedelta(days=x) for x in range(6, 0, -1)]
     dt_seq = DateTimeSeq(dts)
@@ -59,7 +66,7 @@ def test_create_list_datetime_seq(conf):
 
 
 def test_create_list_dt_int_seq(conf):
-    now = datetime.utcnow().replace(microsecond=0)
+    now = datetime.now(UTC).replace(microsecond=0)
     # Create a list of 6 datetimes that started 6 days in the past.
     dts = [now - timedelta(days=x) for x in range(6, 0, -1)]
     dt_int_seq = DateTimeIntSeq(dts)
@@ -71,6 +78,6 @@ def test_create_list_dt_int_seq(conf):
 def test_last_dt_int_seq(conf):
     dt_seq = DateTimeIntSeq([])
     assert (
-        datetime.utcnow().replace(microsecond=0) - timedelta(hours=1)
+        datetime.now(UTC).replace(microsecond=0) - timedelta(hours=1)
         == dt_seq.last()
     )
